package com.ruoyi.ss.onlineLog.mapper;


import com.ruoyi.ss.onlineLog.domain.OnlineLog;

import java.util.List;

/**
 * 在线/离线日志Mapper接口
 *
 * @author 邱贞招
 * @date 2024-07-13
 */
public interface OnlineLogMapper
{
    /**
     * 查询在线/离线日志
     *
     * @param id 在线/离线日志主键
     * @return 在线/离线日志
     */
    public OnlineLog selectEtOnlineLogById(Long id);

    /**
     * 查询在线/离线日志列表
     *
     * @param eOnlineLog 在线/离线日志
     * @return 在线/离线日志集合
     */
    public List<OnlineLog> selectEtOnlineLogList(OnlineLog eOnlineLog);

    /**
     * 新增在线/离线日志
     *
     * @param eOnlineLog 在线/离线日志
     * @return 结果
     */
    public int insertEtOnlineLog(OnlineLog eOnlineLog);

    /**
     * 修改在线/离线日志
     *
     * @param eOnlineLog 在线/离线日志
     * @return 结果
     */
    public int updateEtOnlineLog(OnlineLog eOnlineLog);

    /**
     * 删除在线/离线日志
     *
     * @param id 在线/离线日志主键
     * @return 结果
     */
    public int deleteEtOnlineLogById(Long id);

    /**
     * 批量删除在线/离线日志
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEtOnlineLogByIds(Long[] ids);
}
